@@ -2,7 +2,7 @@
  * Seahorse
  *
  * Copyright (C) 2003 Jacob Perkins
- * Copyright (C) 2004-2005 Nate Nielsen
+ * Copyright (C) 2004-2005 Stefan Walter
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@
 #include "seahorse-widget.h"
 #include "seahorse-pgp-key.h"
 
-SeahorsePGPKey* seahorse_signer_get                 (void);
+SeahorsePGPKey* seahorse_signer_get                 (GtkWindow *parent);
 
 void            seahorse_notify_signatures          (const gchar* data, 
                                                      gpgme_verify_result_t status);
@@ -42,7 +42,7 @@ void            seahorse_notify_signatures_local    (const gchar* data,
                                                      gpgme_verify_result_t status,
                                                      GtkWidget *attachto);
 
-void            seahorse_notify_import              (guint keys);
+void            seahorse_notify_import              (guint keynum, gchar **keys);
                                                      
 void            seahorse_notify_import_local        (guint keys,
                                                      GtkWidget *attachto);
